==> nextcloud-27.1.11.tgz: nextcloud/apps/twofactor_backupcodes/l10n/ga.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "You created two-factor backup codes for your account" : "Chruthaigh tú cóid chúltaca dhá-fhachtóir do do chuntas",
    "Second-factor backup codes" : "Cóid chúltaca dara fachtóir",
    "Generate backup codes" : "Gin cóid chúltaca",
    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "Chuir tú ar chumas fíordheimhnithe dhá-fhachtóir ach níor ghin tú cóid chúltaca fós. Tá siad ag teastáil chun rochtain ar do chuntas a aischur ar eagla go gcaillfidh tú do dhara fachtóir.",
    "Backup code" : "Cód cúltaca",
    "Use backup code" : "Úsáid cód cúltaca",
    "Two factor backup codes" : "Cóid chúltaca dhá fhachtóir",
    "A two-factor auth backup codes provider" : "Soláthraí cóid chúltaca údaráis dhá-fhachtóir",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Gineadh cóid chúltaca. Baineadh úsáid as {used} as {total} cóid.",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Seo iad do chóid chúltaca. Sábháil agus/nó priontáil iad mar ní bheidh tú in ann na cóid a léamh arís ar ball le do thoil",
    "Save backup codes" : "Sábháil cóid chúltaca",
    "Print backup codes" : "Priontáil cóid chúltaca",
    "Regenerate backup codes" : "Athghin cóid chúltaca",
    "If you regenerate backup codes, you automatically invalidate old codes." : "Má athghineann tú cóid chúltaca, déanann tú sean-chóid neamhbhailí go huathoibríoch.",
    "An error occurred while generating your backup codes" : "Tharla earráid agus do chóid chúltaca á nginiúint",
    "{name} backup codes" : "cóid chúltaca {name}",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Bain úsáid as ceann de na cóid chúltaca a shábháil tú agus fíordheimhniú dhá-fhachtóir á socrú agat.",
    "Submit" : "Cuir isteach"
},
"nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");

==> nextcloud-30.0.10.tgz: nextcloud/apps/twofactor_backupcodes/l10n/ga.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "You created two-factor backup codes for your account" : "Chruthaigh tú cóid chúltaca dhá-fhachtóir do do chuntas",
    "Second-factor backup codes" : "Cóid chúltaca dara fachtóir",
    "Generate backup codes" : "Gin cóid chúltaca",
    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "Chuir tú ar chumas fíordheimhnithe dhá-fhachtóir ach níor ghin tú cóid chúltaca fós. Tá siad ag teastáil chun rochtain ar do chuntas a aischur ar eagla go gcaillfidh tú do dhara fachtóir.",
    "Backup code" : "Cód cúltaca",
    "Use backup code" : "Úsáid cód cúltaca",
    "Two factor backup codes" : "Cóid chúltaca dhá fhachtóir",
    "A two-factor auth backup codes provider" : "Soláthraí cóid chúltaca údaráis dhá-fhachtóir",
    "An error occurred while generating your backup codes" : "Tharla earráid agus do chóid chúltaca á nginiúint",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Gineadh cóid chúltaca. Baineadh úsáid as {used} as {total} cóid.",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later." : "Seo iad do chóid chúltaca. Sábháil agus/nó priontáil iad mar ní bheidh tú in ann na cóid a léamh arís ar ball le do thoil.",
    "Save backup codes" : "Sábháil cóid chúltaca",
    "Print backup codes" : "Priontáil cóid chúltaca",
    "Regenerate backup codes" : "Athghin cóid chúltaca",
    "If you regenerate backup codes, you automatically invalidate old codes." : "Má athghineann tú cóid chúltaca, déanann tú sean-chóid neamhbhailí go huathoibríoch.",
    "{name} backup codes" : "cóid chúltaca {name}",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Bain úsáid as ceann de na cóid chúltaca a shábháil tú agus fíordheimhniú dhá-fhachtóir á socrú agat.",
    "Submit" : "Cuir isteach",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Seo iad do chóid chúltaca. Sábháil agus/nó priontáil iad mar ní bheidh tú in ann na cóid a léamh arís ar ball le do thoil"
},
"nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");
